@@ -9,7 +9,6 @@ from lsshu.internal.db import Model
 
 class BaseCRUD(object):
     params_pk = "id"
-    params_delete_tag = "deleted_at"  # 伪删除 字段
     params_model = Model  # 操作模型
     params_db = Session  # db实例
     params_query = None  # 查询实例
@@ -97,25 +96,13 @@ class BaseCRUD(object):
         return data
 
     @classmethod
-    def removed(cls, **kwargs):
+    def count(cls, **kwargs) -> int:
         """
-        伪删除数据
+        多数据
         :param kwargs:
         :return:
         """
-        data = cls.choose_pseudo_deletion(False).where(cls.params_delete_tag, 'is_not', None).action_params(
-            **kwargs).action().params_query.all()
-        return data
-
-    @classmethod
-    def recovery(cls, **kwargs):
-        """
-        恢复 伪删除数据
-        :param kwargs:
-        :return:
-        """
-        data = cls.choose_pseudo_deletion(False).where(cls.params_delete_tag, 'is_not', None).action_params(
-            **kwargs).action().params_query.update({cls.params_delete_tag: None})
+        data = cls.action_params(**kwargs).action().params_query.count()
         return data
 
     @classmethod
@@ -146,14 +133,14 @@ class BaseCRUD(object):
         next_num = page + 1 if pages > page else None
         prev_num = page - 1 if page > 1 else None
         return {
-            "has_next": bool(next_num),  # 如果下一页存在，返回True
-            "has_prev": bool(prev_num),  # 如果上一页存在，返回True
+            # "has_next": bool(next_num),  # 如果下一页存在，返回True
+            # "has_prev": bool(prev_num),  # 如果上一页存在，返回True
             "items": items,  # 当前页的数据列表
-            "next_num": next_num,  # 下一页的页码
-            "prev_num": prev_num,  # 上一页的页码
-            "page": page,  # 当前页码
+            # "next_num": next_num,  # 下一页的页码
+            # "prev_num": prev_num,  # 上一页的页码
+            # "page": page,  # 当前页码
             "pages": pages,  # 总页数
-            "per_page": limit,  # 每页的条数
+            # "per_page": limit,  # 每页的条数
             "total": total,  # 总条数
         }
 
@@ -282,14 +269,15 @@ class BaseCRUD(object):
         :param where:
         :return:
         """
-        _where = cls.params.get('where', [])
-        if (type(where) == list or type(where) == tuple) and (type(where[0]) == list or type(where[0]) == tuple):
-            _where.extend(where)
-        elif (type(where) == list or type(where) == tuple) and type(where[0]) == str:
-            _where.append(where)
-        elif type(where) == str:
-            _where.append((where, *args))
-        cls.params.update({"where": _where})
+        if bool(where):
+            _where = cls.params.get('where', [])
+            if (type(where) == list or type(where) == tuple) and (type(where[0]) == list or type(where[0]) == tuple):
+                _where.extend(where)
+            elif (type(where) == list or type(where) == tuple) and type(where[0]) == str:
+                _where.append(where)
+            elif type(where) == str:
+                _where.append((where, *args))
+            cls.params.update({"where": _where})
         return cls
 
     @classmethod
@@ -365,6 +353,8 @@ class BaseCRUD(object):
                                     fil in
                                     where[2]]
                         query = query.filter(or_(*_filters))
+                elif where[1] in ["between"] and type(where[2]) in [list, tuple] and len(where[2]) == 2:
+                    query = query.filter(getattr(getattr(cls.params_model, where[0]), where[1])(where[2][0], where[2][1]))
                 else:
                     query = query.filter(getattr(getattr(cls.params_model, where[0]), where[1])(where[2]))
         cls.params_query = query
@@ -377,12 +367,13 @@ class BaseCRUD(object):
         :param order:
         :return:
         """
-        _order = cls.params.get('order', [])
-        if type(order[0]) == list or type(order[0]) == tuple:
-            _order.extend(order)
-        elif type(order[0]) == str:
-            _order.append(order)
-        cls.params.update({"order": _order})
+        if bool(order):
+            _order = cls.params.get('order', [])
+            if type(order[0]) == list or type(order[0]) == tuple:
+                _order.extend(order)
+            elif type(order[0]) == str:
+                _order.append(order)
+            cls.params.update({"order": _order})
         return cls
 
     @classmethod
@@ -394,7 +385,7 @@ class BaseCRUD(object):
         query = cls.params_query
         orders = cls.params.get('order', [])
         if bool(orders):
-            if orders and (type(orders) == tuple or type(orders) == list):  # 设置过滤 like
+            if orders and (type(orders) == tuple or type(orders) == list):  # 设置排序
                 for attr_item in orders:
                     query = query.order_by(getattr(getattr(cls.params_model, attr_item[0]), attr_item[1])())
         cls.params_query = query
@@ -557,12 +548,11 @@ class CRUDTree(BaseCRUD):
         """
 
         def query_fun(nodes):
-            return nodes.filter(getattr(cls.params_model, cls.params_delete_tag).is_(None))
+            return nodes
 
         def json_fields_fun(node):
             import copy
             _node = copy.deepcopy(node)
-            delattr(_node, cls.params_delete_tag)
             return {"id": _node.id, "label": _node.name, "node": _node}
 
         return cls.params_model.get_tree(session=db, json=json, json_fields=json_fields_fun if json is True and not json_fields else json_fields,
