@@ -1,4 +1,4 @@
-from sqlalchemy import Column, String, Boolean, Text
+from sqlalchemy import Column, String, Boolean, Text, Integer
 from sqlalchemy_mptt.mixins import BaseNestedSets
 
 from lsshu.internal.db import Model, Engine
@@ -28,3 +28,15 @@ class _ModelOAuthPermissions(Model, BaseNestedSets):
     path = Column(String(50), nullable=False, comment="Path")
     is_menu = Column(Boolean, default=True, comment="是否为菜单")
     is_action = Column(Boolean, default=True, comment="是否为动作权限")
+
+
+class _ModelOAuthAnnexes(Model):
+    """ 附件 """
+    __abstract__ = True
+    filename = Column(String(50), nullable=False, comment="文件名")
+    content_type = Column(String(15), nullable=False, comment="类型")
+    path = Column(String(100), nullable=True, comment="路径")
+    md5 = Column(String(32), nullable=True, comment="md5", index=True)
+    size = Column(Integer, nullable=False, comment="SIZE")
+    width = Column(String(100), nullable=True, comment="宽")
+    height = Column(String(190), nullable=True, comment="高")
